"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommentItem = void 0;
const tslib_1 = require("tslib");
const mobx_react_lite_1 = require("mobx-react-lite");
const react_1 = tslib_1.__importDefault(require("react"));
const ide_components_1 = require("@opensumi/ide-components");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const actions_1 = require("@opensumi/ide-core-browser/lib/components/actions");
const next_1 = require("@opensumi/ide-core-browser/lib/menu/next");
const common_1 = require("../common");
const comment_reactions_view_1 = require("./comment-reactions.view");
const comments_body_1 = require("./comments-body");
const comments_textarea_view_1 = require("./comments-textarea.view");
const comments_module_less_1 = tslib_1.__importDefault(require("./comments.module.less"));
// TODO: 更好的时间格式化组件
const Timestamp = ({ timestamp }) => {
    const formatTimestamp = react_1.default.useMemo(() => {
        const date = new Date(timestamp);
        return (0, ide_core_browser_1.toLocalString)(date);
    }, [timestamp]);
    return react_1.default.createElement("span", { className: comments_module_less_1.default.comment_item_timestamp }, formatTimestamp);
};
const useCommentContext = (contextKeyService, comment) => {
    const menuService = (0, ide_core_browser_1.useInjectable)(next_1.AbstractMenuService);
    const { body, contextValue } = comment;
    const [textValue, setTextValue] = react_1.default.useState('');
    const commentsFeatureRegistry = (0, ide_core_browser_1.useInjectable)(common_1.ICommentsFeatureRegistry);
    const fileUploadHandler = react_1.default.useMemo(() => commentsFeatureRegistry.getFileUploadHandler(), []);
    // set textValue when body changed
    react_1.default.useEffect(() => {
        setTextValue(body);
    }, [body]);
    // Each comment has its own commentContext and commentTitleContext.
    const commentContextService = react_1.default.useMemo(() => contextKeyService.createScoped(), []);
    // it's value will true when textarea is empty
    const commentIsEmptyContext = react_1.default.useMemo(() => commentContextService.createKey('commentIsEmpty', !comment.body), []);
    // below the comment textarea
    const commentContext = react_1.default.useMemo(() => menuService.createMenu(next_1.MenuId.CommentsCommentContext, commentContextService), []);
    // after the comment body
    const commentTitleContext = react_1.default.useMemo(() => menuService.createMenu(next_1.MenuId.CommentsCommentTitle, commentContextService), []);
    const itemCommentContext = react_1.default.useRef(commentContextService.createKey('comment', contextValue));
    react_1.default.useEffect(() => {
        itemCommentContext.current.set(contextValue);
    }, [contextValue]);
    const onChangeTextArea = react_1.default.useCallback((event) => {
        commentIsEmptyContext.set(!event.target.value);
        setTextValue(event.target.value);
    }, []);
    const handleDragFiles = react_1.default.useCallback(async (files) => {
        if (fileUploadHandler) {
            const appendText = await fileUploadHandler(textValue, files);
            setTextValue((text) => {
                const value = text + appendText;
                commentIsEmptyContext.set(!value);
                return value;
            });
        }
    }, [textValue]);
    return [textValue, setTextValue, onChangeTextArea, commentContext, commentTitleContext, handleDragFiles];
};
const ReplyItem = (0, mobx_react_lite_1.observer)(({ reply, thread }) => {
    var _a;
    const { contextKeyService } = thread;
    const { author, label, body, mode, timestamp } = reply;
    const iconUrl = (_a = author.iconPath) === null || _a === void 0 ? void 0 : _a.toString();
    const [textValue, setTextValue, onChangeTextArea, commentContext, commentTitleContext, handleDragFiles] = useCommentContext(contextKeyService, reply);
    // 判断是正常 Inline Text 还是 Markdown Text
    const isInlineText = react_1.default.useMemo(() => {
        const parsedStr = (0, ide_core_browser_1.toMarkdownHtml)(typeof body === 'string' ? body : body.value);
        // 解析出来非纯p标签的则为Markdown Text
        const isInline = /^\<p\>[^<>]+\<\/p\>\n$/.test(parsedStr);
        return isInline;
    }, [body]);
    return (react_1.default.createElement("div", { className: comments_module_less_1.default.reply_item },
        (0, ide_core_browser_1.isUndefined)(mode) || mode === common_1.CommentMode.Preview ? (react_1.default.createElement("div", null, isInlineText ? (react_1.default.createElement(react_1.default.Fragment, null,
            iconUrl && react_1.default.createElement("img", { className: comments_module_less_1.default.reply_item_icon, src: iconUrl, alt: author.name }),
            react_1.default.createElement("span", { className: comments_module_less_1.default.comment_item_author_name }, author.name),
            timestamp && react_1.default.createElement(Timestamp, { timestamp: timestamp }),
            typeof label === 'string' ? react_1.default.createElement("span", { className: comments_module_less_1.default.comment_item_label }, label) : label,
            ' : ',
            react_1.default.createElement("span", { className: comments_module_less_1.default.comment_item_body }, body),
            reply.reactions && reply.reactions.length > 0 && (react_1.default.createElement(comment_reactions_view_1.CommentReactionSwitcher, { className: comments_module_less_1.default.reply_item_title, thread: thread, comment: reply })),
            react_1.default.createElement(actions_1.InlineActionBar, { separator: 'inline', className: comments_module_less_1.default.reply_item_title, menus: commentTitleContext, context: [
                    {
                        thread,
                        comment: reply,
                        menuId: next_1.MenuId.CommentsCommentTitle,
                    },
                ], type: 'icon' }))) : (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement("div", { className: comments_module_less_1.default.comment_item_markdown_header },
                react_1.default.createElement("div", null,
                    iconUrl && react_1.default.createElement("img", { className: comments_module_less_1.default.reply_item_icon, src: iconUrl, alt: author.name }),
                    react_1.default.createElement("span", { className: comments_module_less_1.default.comment_item_author_name }, author.name),
                    timestamp && react_1.default.createElement(Timestamp, { timestamp: timestamp }),
                    typeof label === 'string' ? react_1.default.createElement("span", { className: comments_module_less_1.default.comment_item_label }, label) : label,
                    ' : '),
                react_1.default.createElement(actions_1.InlineActionBar, { separator: 'inline', className: comments_module_less_1.default.reply_item_title, menus: commentTitleContext, context: [
                        {
                            thread,
                            comment: reply,
                            menuId: next_1.MenuId.CommentsCommentTitle,
                        },
                    ], type: 'icon' })),
            react_1.default.createElement(comments_body_1.CommentsBody, { body: body }))))) : (react_1.default.createElement("div", null,
            react_1.default.createElement(comments_textarea_view_1.CommentsTextArea, { value: typeof textValue === 'string' ? textValue : textValue.value, autoFocus: true, onChange: onChangeTextArea, dragFiles: handleDragFiles }),
            react_1.default.createElement(actions_1.InlineActionBar, { className: comments_module_less_1.default.comment_item_reply, menus: commentContext, context: [
                    {
                        thread,
                        comment: reply,
                        body: textValue,
                        menuId: next_1.MenuId.CommentsCommentContext,
                    },
                ], type: 'button', separator: 'inline', afterClick: () => {
                    // restore textarea value
                    setTextValue(body);
                } }))),
        reply.reactions && reply.reactions.length > 0 && react_1.default.createElement(comment_reactions_view_1.CommentReactions, { thread: thread, comment: reply })));
});
exports.CommentItem = (0, mobx_react_lite_1.observer)(({ thread, commentThreadContext, widget }) => {
    var _a;
    const { readOnly, contextKeyService } = thread;
    const [showReply, setShowReply] = react_1.default.useState(false);
    const [replyText, setReplyText] = react_1.default.useState('');
    const [comment, ...replies] = thread.comments;
    const { author, label, body, mode, timestamp } = comment;
    const iconUrl = (_a = author.iconPath) === null || _a === void 0 ? void 0 : _a.toString();
    const [textValue, setTextValue, onChangeTextArea, commentContext, commentTitleContext, handleDragFiles] = useCommentContext(contextKeyService, comment);
    const commentsFeatureRegistry = (0, ide_core_browser_1.useInjectable)(common_1.ICommentsFeatureRegistry);
    const fileUploadHandler = react_1.default.useMemo(() => commentsFeatureRegistry.getFileUploadHandler(), []);
    const replyIsEmptyContext = react_1.default.useMemo(() => contextKeyService.createKey('commentIsEmpty', true), []);
    // modify reply
    function onChangeReply(event) {
        replyIsEmptyContext.set(!event.target.value);
        setReplyText(event.target.value);
    }
    const handleDragFilesToReply = react_1.default.useCallback(async (files) => {
        if (fileUploadHandler) {
            const appendText = await fileUploadHandler(textValue, files);
            setReplyText((text) => {
                const value = text + appendText;
                replyIsEmptyContext.set(!value);
                return value;
            });
        }
    }, [replyText]);
    return (react_1.default.createElement("div", { className: comments_module_less_1.default.comment_item },
        iconUrl && react_1.default.createElement("img", { className: comments_module_less_1.default.comment_item_icon, src: iconUrl, alt: author.name }),
        react_1.default.createElement("div", { className: comments_module_less_1.default.comment_item_content },
            react_1.default.createElement("div", { className: comments_module_less_1.default.comment_item_head },
                react_1.default.createElement("div", { className: comments_module_less_1.default.comment_item_name },
                    react_1.default.createElement("span", { className: comments_module_less_1.default.comment_item_author_name }, author.name),
                    timestamp && react_1.default.createElement(Timestamp, { timestamp: timestamp }),
                    typeof label === 'string' ? react_1.default.createElement("span", { className: comments_module_less_1.default.comment_item_label }, label) : label),
                react_1.default.createElement("div", { className: comments_module_less_1.default.comment_item_actions },
                    comment.reactions && comment.reactions.length > 0 && (react_1.default.createElement(comment_reactions_view_1.CommentReactionSwitcher, { thread: thread, comment: comment })),
                    !readOnly && (react_1.default.createElement(ide_components_1.Button, { className: comments_module_less_1.default.comment_item_reply_button, size: 'small', type: 'secondary', onClick: () => setShowReply(true) }, (0, ide_core_browser_1.localize)('comments.thread.action.reply'))),
                    react_1.default.createElement(actions_1.InlineActionBar, { menus: commentTitleContext, context: [
                            {
                                thread,
                                comment,
                                menuId: next_1.MenuId.CommentsCommentTitle,
                            },
                        ], type: 'button' }))),
            (0, ide_core_browser_1.isUndefined)(mode) || mode === common_1.CommentMode.Preview ? (react_1.default.createElement(comments_body_1.CommentsBody, { body: body })) : (react_1.default.createElement("div", null,
                react_1.default.createElement(comments_textarea_view_1.CommentsTextArea, { value: typeof textValue === 'string' ? textValue : textValue.value, autoFocus: true, onChange: onChangeTextArea, dragFiles: handleDragFiles }),
                react_1.default.createElement(actions_1.InlineActionBar, { className: comments_module_less_1.default.comment_item_context, menus: commentContext, context: [
                        {
                            thread,
                            comment,
                            body: textValue,
                            menuId: next_1.MenuId.CommentsCommentContext,
                        },
                    ], separator: 'inline', type: 'button', afterClick: () => {
                        // restore textarea value
                        setTextValue(body);
                    } }))),
            comment.reactions && comment.reactions.length > 0 && react_1.default.createElement(comment_reactions_view_1.CommentReactions, { thread: thread, comment: comment }),
            (replies.length > 0 || showReply) && (react_1.default.createElement("div", { className: comments_module_less_1.default.comment_item_reply_wrap },
                replies.map((reply) => (react_1.default.createElement(ReplyItem, { key: reply.id, thread: thread, reply: reply }))),
                showReply && (react_1.default.createElement("div", null,
                    react_1.default.createElement(comments_textarea_view_1.CommentsTextArea, { autoFocus: true, value: replyText, onChange: onChangeReply, placeholder: `${(0, ide_core_browser_1.localize)('comments.reply.placeholder')}...`, dragFiles: handleDragFilesToReply }),
                    react_1.default.createElement(actions_1.InlineActionBar, { className: comments_module_less_1.default.comment_item_reply, menus: commentThreadContext, context: [
                            {
                                thread,
                                text: replyText,
                                widget,
                                menuId: next_1.MenuId.CommentsCommentThreadContext,
                            },
                        ], separator: 'inline', type: 'button', afterClick: () => {
                            setReplyText('');
                            setShowReply(false);
                        } }))))))));
});
//# sourceMappingURL=comments-item.view.js.map