"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommentsPanel = void 0;
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const ide_components_1 = require("@opensumi/ide-components");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const common_1 = require("../common");
const comments_module_less_1 = tslib_1.__importDefault(require("./comments.module.less"));
const comment_node_1 = require("./tree/comment-node");
const tree_model_service_1 = require("./tree/tree-model.service");
const CommentsPanel = ({ viewState }) => {
    const commentModelService = (0, ide_core_browser_1.useInjectable)(tree_model_service_1.CommentModelService);
    const [model, setModel] = (0, react_1.useState)();
    const wrapperRef = (0, react_1.useRef)(null);
    const commentsFeatureRegistry = (0, ide_core_browser_1.useInjectable)(common_1.ICommentsFeatureRegistry);
    const { handleTreeBlur } = commentModelService;
    (0, react_1.useEffect)(() => {
        setModel(commentModelService.treeModel);
        const disposable = commentModelService.onDidUpdateTreeModel((model) => {
            setModel(model);
        });
        return () => {
            disposable.dispose();
        };
    }, []);
    const handleTreeReady = (0, react_1.useCallback)((handle) => {
        commentModelService.handleTreeHandler(handle);
    }, [commentModelService]);
    const renderTreeNode = (0, react_1.useCallback)((props) => (react_1.default.createElement(comment_node_1.CommentNodeRendered, { item: props.item, itemType: props.itemType, decorations: commentModelService.decorations.getDecorations(props.item), defaultLeftPadding: 8, onTwistierClick: commentModelService.handleTwistierClick, onClick: commentModelService.handleItemClick, leftPadding: 8 })), [model]);
    const commentsPanelOptions = (0, react_1.useMemo)(() => commentsFeatureRegistry.getCommentsPanelOptions(), []);
    const headerComponent = (0, react_1.useMemo)(() => commentsPanelOptions.header, [commentsPanelOptions]);
    const defaultPlaceholder = (0, react_1.useMemo)(() => (react_1.default.createElement("div", { className: comments_module_less_1.default.panel_placeholder }, commentsPanelOptions.defaultPlaceholder || (0, ide_core_browser_1.localize)('comments.panel.placeholder'))), [commentsPanelOptions]);
    const renderCommentTree = (0, react_1.useCallback)(() => {
        if (model) {
            return (react_1.default.createElement(ide_components_1.RecycleTree, { height: viewState.height - ((headerComponent === null || headerComponent === void 0 ? void 0 : headerComponent.height) || 0), itemHeight: comment_node_1.COMMENT_TREE_NODE_HEIGHT, onReady: handleTreeReady, model: model, placeholder: () => defaultPlaceholder }, renderTreeNode));
        }
        else {
            return defaultPlaceholder;
        }
    }, [model, headerComponent, viewState.height]);
    return (react_1.default.createElement("div", { className: comments_module_less_1.default.comment_panel, tabIndex: -1, onBlur: handleTreeBlur, ref: wrapperRef }, headerComponent === null || headerComponent === void 0 ? void 0 :
        headerComponent.component,
        renderCommentTree()));
};
exports.CommentsPanel = CommentsPanel;
//# sourceMappingURL=comments-panel.view.js.map