"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.COMMENT_TREE_NODE_HEIGHT = exports.CommentNodeRendered = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const react_1 = tslib_1.__importStar(require("react"));
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const tree_node_defined_1 = require("./tree-node.defined");
const tree_node_module_less_1 = tslib_1.__importDefault(require("./tree-node.module.less"));
const CommentNodeRendered = ({ item, defaultLeftPadding = 8, leftPadding = 8, decorations, onClick, onTwistierClick, }) => {
    const handleClick = (0, react_1.useCallback)((ev) => {
        if (item.onSelect) {
            // 当节点绑定了自定义函数时，不通过默认逻辑处理点击事件
            item.onSelect(item);
        }
        else {
            onClick(ev, item);
        }
    }, [onClick]);
    const handleTwistierClick = (0, react_1.useCallback)((ev) => {
        onTwistierClick(ev, item);
    }, [onTwistierClick]);
    const paddingLeft = `${defaultLeftPadding +
        (item.depth || 0) * (leftPadding || 0) +
        (tree_node_defined_1.CommentContentNode.is(item) ? 16 : tree_node_defined_1.CommentFileNode.is(item) ? 0 : 28)}px`;
    const renderedNodeStyle = {
        height: exports.COMMENT_TREE_NODE_HEIGHT,
        lineHeight: `${exports.COMMENT_TREE_NODE_HEIGHT}px`,
        paddingLeft,
    };
    const renderIcon = (0, react_1.useCallback)((node) => {
        if (tree_node_defined_1.CommentContentNode.is(node) || tree_node_defined_1.CommentFileNode.is(node)) {
            return (react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.icon, node.icon), style: {
                    height: exports.COMMENT_TREE_NODE_HEIGHT,
                    lineHeight: `${exports.COMMENT_TREE_NODE_HEIGHT}px`,
                } }));
        }
    }, []);
    const renderDisplayName = (0, react_1.useCallback)((node) => {
        if (tree_node_defined_1.CommentContentNode.is(node)) {
            return (react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.segment, tree_node_module_less_1.default.displayname) }, node.renderedLabel ? (node.renderedLabel) : (react_1.default.createElement(react_1.default.Fragment, null,
                node.comment,
                react_1.default.createElement("span", { className: tree_node_module_less_1.default.separator }, "\u00B7"),
                node.author.name))));
        }
        else {
            return react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.segment, tree_node_module_less_1.default.displayname) }, node.renderedLabel);
        }
    }, []);
    const renderDescription = (0, react_1.useCallback)((node) => (react_1.default.createElement("div", { className: (0, classnames_1.default)(tree_node_module_less_1.default.segment_grow, tree_node_module_less_1.default.description) }, node.renderedDescription)), []);
    const renderFolderToggle = (0, react_1.useCallback)((node) => (react_1.default.createElement("div", { onClick: handleTwistierClick, className: (0, classnames_1.default)(tree_node_module_less_1.default.segment, tree_node_module_less_1.default.expansion_toggle, (0, ide_core_browser_1.getIcon)('right-arrow'), {
            [`${tree_node_module_less_1.default.mod_collapsed}`]: !node.expanded,
        }) })), [handleTwistierClick]);
    const renderTwice = (0, react_1.useCallback)((node) => {
        if (tree_node_defined_1.CommentFileNode.is(node) || (node === null || node === void 0 ? void 0 : node.isAllowToggle)) {
            return renderFolderToggle(node);
        }
    }, []);
    const getItemTooltip = (0, react_1.useCallback)(() => item.tooltip, [item]);
    return (react_1.default.createElement("div", { key: item.id, onClick: handleClick, title: getItemTooltip(), className: (0, classnames_1.default)(tree_node_module_less_1.default.comment_node, decorations ? decorations.classlist : null), style: renderedNodeStyle, "data-id": item.id },
        react_1.default.createElement("div", { className: tree_node_module_less_1.default.content },
            renderTwice(item),
            renderIcon(item),
            react_1.default.createElement("div", { className: tree_node_module_less_1.default.overflow_wrap },
                renderDisplayName(item),
                renderDescription(item)))));
};
exports.CommentNodeRendered = CommentNodeRendered;
exports.COMMENT_TREE_NODE_HEIGHT = 22;
//# sourceMappingURL=comment-node.js.map